I don't hate this plan, but I do want to state that it really goes against the idea of being agnostic. This plan depends a lot on .claude and how it functions currently. And I think that that gets away from what our true end goal of the project is, which is to be agnostic to whatever coding agents are available and models and such like and things like that. We really want to build this so that it still works in six months when all of this stuff changes.


I personally like the idea of putting it as a tool in the Pyproject.com or something along those lines that seems like it would fit into most structures of code bases easily.